summaryrefslogtreecommitdiff
path: root/TAO/orbsvcs/orbsvcs/LoadBalancing
diff options
context:
space:
mode:
authordai_y <dai_y@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2009-12-04 21:02:10 +0000
committerdai_y <dai_y@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2009-12-04 21:02:10 +0000
commite791ad22ad1446fa08de128b665bdb5a53cca96e (patch)
treef61666fa8ac9273ade48e251451146e2281f30fa /TAO/orbsvcs/orbsvcs/LoadBalancing
parent9755b796bbf731e11fe3b019e898c03266a771ed (diff)
downloadATCD-e791ad22ad1446fa08de128b665bdb5a53cca96e.tar.gz
Fri Dec 4 21:00:38 UTC 2009 Yan Dai <dai_y@ociweb.com>
Diffstat (limited to 'TAO/orbsvcs/orbsvcs/LoadBalancing')
-rw-r--r--TAO/orbsvcs/orbsvcs/LoadBalancing/LB_LoadManager.cpp14
-rw-r--r--TAO/orbsvcs/orbsvcs/LoadBalancing/LB_LoadManager.h13
2 files changed, 10 insertions, 17 deletions
diff --git a/TAO/orbsvcs/orbsvcs/LoadBalancing/LB_LoadManager.h b/TAO/orbsvcs/orbsvcs/LoadBalancing/LB_LoadManager.h
index 6fdcfcbcdbd..49d4f1a30d4 100644
--- a/TAO/orbsvcs/orbsvcs/LoadBalancing/LB_LoadManager.h
+++ b/TAO/orbsvcs/orbsvcs/LoadBalancing/LB_LoadManager.h
@@ -22,10 +22,6 @@
#pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */
-#if defined (__BORLANDC__)
-# pragma option push -w-hid
-#endif /* __BORLANDC__ */
-
#include "orbsvcs/LoadBalancing/LB_LoadAlertMap.h"
#include "orbsvcs/LoadBalancing/LB_MonitorMap.h"
#include "orbsvcs/LoadBalancing/LB_LoadListMap.h"
@@ -273,9 +269,9 @@ public:
/// Initialize the load balancer. This will cause a child POA to be
/// created with the appropriate policies to support ServantLocators
/// (i.e. for the MemberLocator).
- void init (ACE_Reactor * reactor,
- CORBA::ORB_ptr orb,
- PortableServer::POA_ptr root_poa);
+ void initialize (ACE_Reactor * reactor,
+ CORBA::ORB_ptr orb,
+ PortableServer::POA_ptr root_poa);
protected:
@@ -428,9 +424,6 @@ private:
ACE_Time_Value ping_interval_;
};
-#if defined (__BORLANDC__)
-# pragma option pop
-#endif /* _MSC_VER */
TAO_END_VERSIONED_NAMESPACE_DECL
diff --git a/TAO/orbsvcs/orbsvcs/LoadBalancing/LB_LoadManager.cpp b/TAO/orbsvcs/orbsvcs/LoadBalancing/LB_LoadManager.cpp
index adf715f361f..d6969da39b5 100644
--- a/TAO/orbsvcs/orbsvcs/LoadBalancing/LB_LoadManager.cpp
+++ b/TAO/orbsvcs/orbsvcs/LoadBalancing/LB_LoadManager.cpp
@@ -62,11 +62,11 @@ TAO_LB_LoadManager::TAO_LB_LoadManager (int ping_timeout,
{
this->pull_handler_.initialize (&this->monitor_map_, this);
// @note "this->init()" is not called here (in the constructor)
// since it may thrown an exception. Throwing an exception in
// a constructor in an emulated exception environment is
// problematic since native exception semantics cannot be
// reproduced in such a case. As such, init() must be called
// by whatever code instantiates this LoadManager.
}
@@ -618,7 +618,7 @@ TAO_LB_LoadManager::create_object (
PortableGroup::GenericFactory::FactoryCreationId_out
factory_creation_id)
{
-// this->init ();
+// this->initialize ();
PortableGroup::Criteria new_criteria (the_criteria);
@@ -765,9 +765,9 @@ TAO_LB_LoadManager::next_member (const PortableServer::ObjectId & oid)
}
void
-TAO_LB_LoadManager::init (ACE_Reactor * reactor,
- CORBA::ORB_ptr orb,
- PortableServer::POA_ptr root_poa)
+TAO_LB_LoadManager::initialize (ACE_Reactor * reactor,
+ CORBA::ORB_ptr orb,
+ PortableServer::POA_ptr root_poa)
{
ACE_ASSERT (!CORBA::is_nil (orb));
ACE_ASSERT (!CORBA::is_nil (root_poa));
@@ -867,7 +867,7 @@ TAO_LB_LoadManager::init (ACE_Reactor * reactor,
if (this->ping_interval_ > ACE_Time_Value::zero && this->activate(THR_NEW_LWP | THR_JOINABLE, 1) != 0)
{
ACE_ERROR((LM_ERROR,
- ACE_TEXT ("(%P|%t)TAO_LB_LoadManager::init failed to activate ")
+ ACE_TEXT ("(%P|%t)TAO_LB_LoadManager::initialize failed to activate ")
ACE_TEXT ("thread to validate connection.\n")));
throw CORBA::INTERNAL ();
}
@@ -62,11 +62,11 @@ TAO_LB_LoadManager::TAO_LB_LoadManager (int ping_timeout,
{
this->pull_handler_.initialize (&this->monitor_map_, this);
- // @note "this->init()" is not called here (in the constructor)
+ // @note "this->initialize()" is not called here (in the constructor)
// since it may thrown an exception. Throwing an exception in
// a constructor in an emulated exception environment is
@@ -62,11 +62,11 @@ TAO_LB_LoadManager::TAO_LB_LoadManager (int ping_timeout,
// a constructor in an emulated exception environment is
// problematic since native exception semantics cannot be
- // reproduced in such a case. As such, init() must be called
+ // reproduced in such a case. As such, initialize() must be called
// by whatever code instantiates this LoadManager.
}